pub fn to_string<T: ?Sized>(value: &T) -> Result<String> where
    T: Serialize, 
Serialize the given data structure as a String of YAML.

Serialization can fail if T’s implementation of Serialize decides to return an error.